@@ -156,25 +156,20 @@ This method automatically format the value as 8, 16 or 32 bits array."
            (setf value tmp))
           (16
            (cl-assert (= (* 2 value-len) (length tmp)))
+           (setf value (make-vector value-len 0))
            (if ~lsb
-               (dotimes (_ value-len)
-                 (setf value (vconcat value
-                                      (vector (xcb:-unpack-u2-lsb tmp 0))))
-                 (setq tmp (substring tmp 2)))
-             (dotimes (_ value-len)
-               (setf value (vconcat value
-                                    (vector (xcb:-unpack-u2 tmp 0))))
-               (setq tmp (substring tmp 2)))))
+               (dotimes (idx value-len)
+                 (aset value idx (xcb:-unpack-u2-lsb tmp (* 2 idx))))
+             (dotimes (idx value-len)
+               (aset value idx (xcb:-unpack-u2 tmp (* 2 idx))))))
           (32
            (cl-assert (= (* 4 value-len) (length tmp)))
+           (setf value (make-vector value-len 0))
            (if ~lsb
-               (dotimes (_ value-len)
-                 (setf value (vconcat value
-                                      (vector (xcb:-unpack-u4-lsb tmp 0))))
-                 (setq tmp (substring tmp 4)))
-             (dotimes (_ value-len)
-               (setf value (vconcat value (vector (xcb:-unpack-u4 tmp 0))))
-               (setq tmp (substring tmp 4)))))
+               (dotimes (idx value-len)
+                 (aset value idx (xcb:-unpack-u4-lsb tmp (* 4 idx))))
+             (dotimes (idx value-len)
+               (aset value idx (xcb:-unpack-u4 tmp (* 4 idx))))))
           (_ (cl-assert nil)))))
     retval))
 
